summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorVailin Choi <vchoi@hdfgroup.org>2015-07-05 22:33:57 (GMT)
committerVailin Choi <vchoi@hdfgroup.org>2015-07-05 22:33:57 (GMT)
commit6d36ca2303d9a67e6fa4bd8877e8eccddcd92f53 (patch)
tree2bde5e86d94d0db0db5381fa28808cea9ff394cc /src
parentf3b42904a5069df96df36989876351bb8302b251 (diff)
downloadhdf5-6d36ca2303d9a67e6fa4bd8877e8eccddcd92f53.zip
hdf5-6d36ca2303d9a67e6fa4bd8877e8eccddcd92f53.tar.gz
hdf5-6d36ca2303d9a67e6fa4bd8877e8eccddcd92f53.tar.bz2
[svn-r27338] Bring revision #24747 from revise_chksum_retry branch to revise_chunks.
Plus couple fixes: 1) test/test_swmr.c: fix to use H5Dopen2() 2) test/noencoder.h5: clear status_flags in superblock
Diffstat (limited to 'src')
-rw-r--r--src/H5O.c33
-rw-r--r--src/H5Opublic.h6
2 files changed, 19 insertions, 20 deletions
diff --git a/src/H5Opublic.h b/src/H5Opublic.h
index 12d0780..af7bed1 100644
--- a/src/H5Opublic.h
+++ b/src/H5Opublic.h
@@ -184,9 +184,9 @@ H5_DLL herr_t H5Ovisit_by_name(hid_t loc_id, const char *obj_name,
H5_DLL herr_t H5Oclose(hid_t object_id);
H5_DLL herr_t H5Oflush(hid_t obj_id);
H5_DLL herr_t H5Orefresh(hid_t oid);
-H5_DLL herr_t H5Ocork(hid_t object_id);
-H5_DLL herr_t H5Ouncork(hid_t object_id);
-H5_DLL herr_t H5Ois_corked(hid_t object_id, hbool_t *corked);
+H5_DLL herr_t H5Odisable_mdc_flushes(hid_t object_id);
+H5_DLL herr_t H5Oenable_mdc_flushes(hid_t object_id);
+H5_DLL herr_t H5Oare_mdc_flushes_disabled(hid_t object_id, hbool_t *are_disabled);
diff --git a/src/H5O.c b/src/H5O.c
index bc40147..e1b4793 100644
--- a/src/H5O.c
+++ b/src/H5O.c
@@ -1087,7 +1087,7 @@ done:
/*-------------------------------------------------------------------------
- * Function: H5Ocork
+ * Function: H5Odisable_mdc_flushes
*
* Purpose: To "cork" an object:
* --keep dirty entries assoicated with the object in the metadata cache
@@ -1100,7 +1100,7 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5Ocork(hid_t object_id)
+H5Odisable_mdc_flushes(hid_t object_id)
{
H5O_loc_t *oloc; /* Object location */
herr_t ret_value = SUCCEED; /* Return value */
@@ -1117,11 +1117,11 @@ H5Ocork(hid_t object_id)
done:
FUNC_LEAVE_API(ret_value)
-} /* H5Ocork() */
+} /* H5Odisable_mdc_flushes() */
/*-------------------------------------------------------------------------
- * Function: H5Ouncork
+ * Function: H5Oenable_mdc_flushes
*
* Purpose: To "uncork" an object
* --release keeping dirty entries associated with the object
@@ -1135,7 +1135,7 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5Ouncork(hid_t object_id)
+H5Oenable_mdc_flushes(hid_t object_id)
{
H5O_loc_t *oloc; /* Object location */
herr_t ret_value = SUCCEED; /* Return value */
@@ -1153,15 +1153,15 @@ H5Ouncork(hid_t object_id)
done:
FUNC_LEAVE_API(ret_value)
-} /* H5Ouncork() */
+} /* H5Oenable_mdc_flushes() */
/*-------------------------------------------------------------------------
- * Function: H5Ois_corked
+ * Function: H5Oare_mdc_flushes_disabled
*
* Purpose: Retrieve the object's "cork" status in the parameter "corked":
* TRUE if the object is "corked"
* FALSE if the object is not "corked"
* Return error if the parameter "corked" is not supplied
*
* Return: Success: Non-negative
* Failure: Negative
@@ -1171,29 +1171,29 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5Ois_corked(hid_t object_id, hbool_t *corked)
+H5Oare_mdc_flushes_disabled(hid_t object_id, hbool_t *are_disabled)
{
H5O_loc_t *oloc; /* Object location */
herr_t ret_value = SUCCEED; /* Return value */
FUNC_ENTER_API(FAIL)
- H5TRACE2("e", "i*b", object_id, corked);
+ H5TRACE2("e", "i*b", object_id, are_disabled);
/* Check args */
/* Get the object's oloc */
if((oloc = H5O_get_loc(object_id)) == NULL)
HGOTO_ERROR(H5E_ATOM, H5E_BADVALUE, FAIL, "unable to get object location from ID")
- if(!corked)
+ if(!are_disabled)
HGOTO_ERROR(H5E_ATOM, H5E_BADVALUE, FAIL, "unable to get object location from ID")
/* Get the cork status */
- if(H5AC_cork(oloc->file, oloc->addr, H5AC__GET_CORKED, corked) < 0)
+ if(H5AC_cork(oloc->file, oloc->addr, H5AC__GET_CORKED, are_disabled) < 0)
HGOTO_ERROR(H5E_ATOM, H5E_BADVALUE, FAIL, "unable to retrieve an object's cork status")
done:
FUNC_LEAVE_API(ret_value)
-} /* H5Ois_corked() */
+} /* H5Oare_mdc_flushes_disabled() */
/*-------------------------------------------------------------------------
@@ -1550,7 +1550,6 @@ done:
herr_t
H5O_close(H5O_loc_t *loc)
{
- hbool_t corked;
herr_t ret_value = SUCCEED; /* Return value */
FUNC_ENTER_NOAPI(FAIL)
@@ -1153,15 +1153,15 @@ H5Ouncork(hid_t object_id)
*
- * Purpose: Retrieve the object's "cork" status in the parameter "corked":
- * TRUE if the object is "corked"
- * FALSE if the object is not "corked"
- * Return error if the parameter "corked" is not supplied
+ * Purpose: Retrieve the object's "cork" status in the parameter "are_disabled":
+ * TRUE if mdc flushes for the object is disabled
+ * FALSE if mdc flushes for the object is not disabled
+ * Return error if the parameter "are_disabled" is not supplied
*
* Return: Success: Non-negative